@@ -1,4 +1,4 @@
-within.mitml.list <- function(data, expr, ignore=NULL, ...){
+within.mitml.list <- function(data, expr, ignore = NULL, ...){
 # evaluate an expression for a list of data sets, then return altered data sets
 
   expr <- substitute(expr)
@@ -13,11 +13,12 @@ within.mitml.list <- function(data, expr, ignore=NULL, ...){
     nD <- length(del <- setdiff(names(x), (nl <- names(l))))
     x[nl] <- l
     if(nD){
-      x[del] <- if(nD==1){ NULL } else { vector("list", nD) }
+      x[del] <- if(nD == 1){ NULL } else { vector("list", nD) }
     }
     x
   })
-  class(out) <- c("mitml.list","list")
-  out
+
+  class(out) <- c("mitml.list", "list")
+  return(out)
 
 }
